bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 2. Aventiure
___________________________________________________ #### <Auentv> von Sivride wie der erzogen wart
| ### Do wohs in nider landen eins edeln kuniges chint ### des vater der hiez Sigemvnt sin mvter Sigelint ### ineiner richen burge witen wol bechant ### nidene bi dem Rine div was ze Santen genant
###### 20 | ### Sifrit was geheizen der snelle degen gvot ### er versvchte vil der riche dvrch ellenthaften mvot ### durch sines libes sterche svochter fremdiv lant ### hey waz er sneller degene sit ze Buregonden vant
###### 21 | ### Ê daz der degen chvne vol whse zeman ### do het er solhiv wnder mit siner hant getan ### da von man immer mere mac singen vn– sagen ### des wir indisen stunden mvzen vil von im gedagen
###### 22 | ### In sinen besten ziten bi sinen iungen tagen ### man mohte michel wnder von Sifriden sagen ### waz eren an im whse vn– wie schone was sin lip ### des heten in zeminne div vil wetlichen wip
| ### <MAn> zoh in mit dem vlize als im daz wol gezam ### von sin selbes tvgenden [2r]waz zvht er an sich nam ### des wrden sit gezieret sines vater lant ### daz man in zallen dingen so rehte herlichen vant
###### 24 | ### Uil selten ane hvote man riten lie daz kint ### in hiez mit wæte zieren sin mvter Sygelint ### sin pflagen ovch die wisen den ere was bekant ### des moht er wol gewinnen beidiv lvot vn– lant
###### 25 | ### Nv was er inder sterche daz er wol waffen trvoch ### swes er da zv bedorfte des lag an im genvoch ### do begvnder sinnen werben schoniv wip ### die trvoten wol mit eren den sinen wetlichen lip
###### 26 | ### Do hiez sin vater <Sigemvnt> chunden sinen man ### er wolde hochgecite mit lieben friunden han ### div mære man do furte in vremder kunige lant ### den gesten vn– den chunden gap man rosse vn– ovch gewant
| ### Swa man vant deheinen der ritter solde sin ### von art der sinen mage div edeln kindelin ### dv ladet man zv dem lande durch die hochgecit ### mit samt dem iungen kunige swert genamen si sit
###### 28 | ### Von der hochgecite man mohte wnder sagen ### Sigemvnt vn– Sigelint die chvnden wol beiagen ### mit gvte michel ere des teilte vil ir hant ### des sah man vil der fremden zvzin riten indaz lant
###### 29 | ### Vier hundert swert degene die solden tragen chleit ### mit dem iungen kunige vil manic schoniv meit ### mit werche was vnmvzich wande si in waren holt ### vil der edeln steine die frowen leiten in daz golt
###### 30 | ### die si mit porten wolden wrchen vf ir wat ### den stolzen swertdegenen des enwas niht rat ### der wirt der hiez do sidelen vil manigem chvnen man ### zeinen svnewenden da er die hochgecite wolde han
| ### Do gie zeinem mvnster vil manic richer kneht ### vn– vil der edeln ritter die wisen heten reht ### daz si den tumben dienten als in was ê getan ### si heten kvrzwile vn– ovch vil maniger vrovden wan
###### 32 | ### Got man zen eren ein messe sanc ### do wart von den lvten vil michel der gedranch ### da si zeritter wrden nach ritterlicher ê ### mit also grozzen eren daz wetlich immer me erge
###### 33 | ### Si liefen da si funden gesatelt manic march ### in hofe Sigemundes der bvhurt wart so starch ### daz man erdiezen horte palas vn– sal ### die hochgemvten degene heten vrolichen scal
###### 34 | ### Von wisen vn– von tumben man horte manigen stoz ### daz der schefte brechen gein dem lufte doz ### trunzvne sach man vliegen fur den palas dan ### da sahen churzewile beidiv wip vn– ovch die man
| ### Der chunich bat iz lazen do zoch man dan div march ### man sach ovch da zebrochen uil manige bukkel starch ### vil der edeln steine geuellet vf daz gras ### an liehten schildes spangen von hvrten daz geschehen was
###### 36 | ### Do giengens wirtes geste da man in sitzen riet ### vil der edeln spise si von der mvode schiet ### vn– win der aller beste den man mit vollen trvoch ### den vremden vn– den [2v]kunden bot man eren da genvoch
###### 37 | ### Solcher kurcewile si pflagen al den tac ### vil der varnder diete rwoe sich bewac ### si dieten nach der gabe die man da riche vant ### des wart mit lobe gezieret allez Sigemundes lant
###### 38 | ### Der herre hiez do lihen sinen svn den iungen man ### lant un– purge als er e het getan ### den sinen swertgenôzen gap do vil sine hant ### do liebt in do div reise daz si chomen in daz lant
| ### Div hochgecite do werte vnz an den sibenden tac ### Sigelint div riche nach alten siten pflac ### durch ir kindes liebe geben rotez golt ### si kundez wol gedienen daz si ir svne warn holt
###### 40 | ### Lutzel deheinen varnden armen man da vant ### rosse vn– kleider daz stvop in von der hant ### sam si ze lebene heten mer deheinen tac ### ich wene ie ingesinde so grozzer milte gepflac
| ### Mit lobelichen eren schiet sich div hochgecit ### von des landes herren hort man wol sit ### daz si den iungen wolden zeime vogete han ### des enwolde in do niht volgen Sifrit der wêtlich man
###### 42 | ### Sit daz noch beide lebten Sigemunt vn– Sigelint ### niht wolde tragen krone noch ir liebez kint ### doch wolder wesen herre fur allen den gewalt ### des in den landen vorhte der degen kvn vn– balt
###### 43 | ### In dorfte niemen schelten sit do er wafen genam ### ia gerwoete vil selten der reche lobesam ### svchte niwan striten sin ellenthaftiv hant ### tet in zallen ziten in vremeden richen wol bekant

<<< Übersicht <<< vorige Seite nächste Seite >>>